#
# spec file for package cutterff
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cutterff
Version:        1.3
Release:        1.5
Summary:        Video cutter that uses FFmpeg and GTK+
License:        GPL-3.0-only
Group:          Productivity/Multimedia/Video/Editors and Convertors
URL:            https://cutterff.sourceforge.io/
Source0:        https://master.dl.sourceforge.net/project/cutterff/%{version}/cutterff-%{version}-src.tar.bz2
Source1:        %{name}.desktop
BuildRequires:  desktop-file-utils
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libswscale)

%description
CutterFF is a program for cutting videos using FFmpeg and GTK+.
It does not decode/encode the streams, it only copies them.

Features
 - Selecting which streams written to the output
 - Selecting the format and bitstream filters
 - Choose a program if video contains more than one
 - Set cutpoints everywhere in the video
 - Many formats and codecs supported by FFmpeg
 - Log window for displaying FFmpeg messages

%lang_package

%prep
%autosetup

%build
export CPPFLAGS="%{optflags}"
%configure
%make_build

%install
%make_install
install -D -m644 %{name}.xpm %{buildroot}%{_datadir}/pixmaps/%{name}.xpm
install -D -m644 %{SOURCE1} %{buildroot}%{_datadir}/applications/%{name}.desktop

%find_lang %{name}

%files
%license COPYING
%doc README ChangeLog
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.xpm

%files lang -f %{name}.lang

%changelog
* Tue Aug 27 2024 Dave Plater <davejplater@gmail.com>
- revert to ffmpeg-7
* Tue Aug 27 2024 Dave Plater <davejplater@gmail.com>
- Force ffmpeg-6 library use to fix build
* Tue Aug 27 2024 Christophe Marin <christophe@krop.fr>
- Update to 1.3 to add support for FFmpeg 7. Check the ChangeLog
  file for the full list of changes.
* Wed Jul 13 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.0.2:
  * gui.c:
    + changed in 'cff_gui_dialog_progress_callback'
    Gui_PRIORITY_REDRAW to G_PRIORITY_HIGH_IDLE
    + changed in 'cff_gui_logwindow_add_timeout'
    G_PRIORITY_HIGH to GTK_TEXT_VIEW_PRIORITY_VALIDATE
    + if the first character of the log string is '\r',
    the last line will be overwritten (Last message
    repeated x times). See 'cff_gui_logwindow_mainthread'
    and 'cff_gui_logwindow_cb'
  * ffmpeg.c:
    + works with FFmpeg version 5.0.1
    + in 'cff_ffmpeg_get_image_format_names' looking
    for the codec_id (TIFF, GIF ...) if the encoder
    has not the mime type 'image'
    + test in 'cff_ffmpeg_get_encoder_names' whether
    the encoder supports the pixel format of the input
    + removed in 'cff_ffmpeg_encoder_new' the options
    for 'b-frames', 'gop' and 'sc_threshold'
    + in 'cff_ffmpeg_copy_softcut' forgot to free the
    frame if packet allocation fails
    + 'level &= 0x00FF' in 'cff_ffmpeg_log_callback'
    + get the parent class in 'cff_ffmpeg_log_callback'
    with 'avr' may crash. Right way is using 'ptr'
    + 'skip_prefix' in 'cff_ffmpeg_log_callback' to
    append the next string to the current
    + compare the string in 'cff_ffmpeg_log_callback'
    to the previous one. If equal throw the message
    "Last message repeated x times"
    + some improvements in'cff_ffmpeg_get_frame' for
    proper decoding. Sometimes a frame may report a
    wrong picture type, or a key frame which is not
    at this position, or the frame is not correct
    displayed.
  * ffmpeg.h: including 'libavcodec/bsf.h' (FFmpeg 5.0.1)
- Drop lang package Recommends, no longer needed, nor wanted.
* Thu Sep  9 2021 enzokiel@kabelmail.de
- Update to version 1.0.1
  * gui.c
    + if encoding (softcut enabled) has finished, the text in the
    progressbar may not disappear. Fixed!
  * ffmpeg.c
    + if saving a file with softcut more than once the automatic
    enabling of 'h264_mp4toannexb' or 'hevc_mp4toannexb' fails.
    Fixed!
    + in 'cff_ffmpeg_copy_write_frame_softcut' the PTS assignment
    may wrong, 'pts -= pts_diff' followed by 'pts = pptr->dts'.
    Fixed!
    + 'av_packet_int' replaced with 'av_packet_alloc'
    + 'av_packet_ref' replaced with 'av_packet_clone'
* Tue Aug 31 2021 enzokiel@kabelmail.de
- Update to version 1.0
  * main.c
    + replaced 'GLIB_MAJOR_VERSION' with
    'GLIB_MINOR_VERSION' and 'glib_major_version'
    with 'glib_minor_version'
  * gui.c
    + setting '-GtkMenuBar-shadow-type' only for
    versions < 3.20 (GTK-3 only)
    + if closing a file with unsaved cutpoints a
    dialog asks for discarding changes
    + replaced in 'cff_gui_css_load_from_data'
    'gtk_style_context_add_provider_for_screen'
    with 'gtk_style_context_add_provider'
    + changed priority in 'cff_gui_logwindow_color_set'
    from 'GTK_STYLE_PROVIDER_PRIORITY_APPLICATION' to
    '..._USER' (GTK-3 only)
    + changed tag color and font in 'textview' to
    GTK-2 'gtk_widget_modify_...' or
    GTK-3 'cff_gui_css_load_from_data'
    + in 'cff_gui_logwindow_color_parse' converting
    'rgb(r,g,b)' to '#rrggbb' (GTK-2 only)
    + popup in 'cff_gui_file_save' for selecting the
    encoder for soft cutting
    + may hang if log was set to 'debug'. So
    'g_main_context_invoke_full' in 'cff_gui_logwindow_cb'
    was removed, 'cff_gui_logwindow_mainthread' is now
    called every 5ms using 'g_timeout_add_full'
    + remove last '\n' from log string in 'cff_gui_logwindow_cb'
    + '_textview_scroll_to_iter' in 'cff_gui_logwindow_cb'
    was removed. Now down scrolling is done using the
    signal 'changed', and setting the new value in
    'cff_gui_logwindow_adjustment' with the function
    'gtk_adjustment_set_value'
    + the slider is now 'GtkScale'
    + using 'Cairo' instead of 'GdkDraw' (GTK-2 only)
  * ffmpeg.c
    + 'cff_ffmpeg_print_codecs_for_id': codecs separated
    by commas, last space in front of terminating ')'
    removed
    + softcut is de- and encoding frames at the cutpoint(s)
    + stream-sync starts copying packets if the timestamp
    is greater or equal than the cutpoint
    + test if bitstream filter 'mp4toannexb' is needed for
    encoding in 'cff_ffmpeg_get_frame_dts' (h.264 + h.265)
    + 'cff_ffmpeg_copy_open': if 'avformat_transfer_internal_
    stream_timing_info' failed, try '(st->oStream)->time_
    base = (st->iStream)->time_base' before 'av_stream_get_
    codec_timebase'
    + if the first DVB subtitle frame should clear a subtitle,
    it is dropped (no subtitle shown yet). This will also
    compute the right stream duration
  * tools-gtk.c
    + renamed 'guitl_' to 'cff_guitl_'
    + moved 'cff_gui_beep' to 'cff_guitl_beep'
    + 'cff_guitl_window_destroy' sets 'gWindata.topwin'
    to NULL, if the main window is not on the top
    + 'cff_guitl_dialog_icon' sets 'gWindata.topwin' to
    'gWindata.mainwin', is the top window is NULL
    + changed signal 'size-allocate' in 'cff_guitl_window_setup'
    to 'configure-event'
* Tue Aug  6 2019 enzokiel@kabelmail.de
- Update to version 0.9
  + gui.c
  - if Num-Lock is activated, depending on the OS and GUI no
    navigation may possible. Now the functions only breaks if the
    Control-key is pressed.
  - 'cff_gui_video_frame_button' is the right button equal to the
    shift key.
  + ffmpeg.c
  - 'cff_ffmpeg_get_stream_from_index' may return wrong or no
    streams, if the file contains more than one program, and some
    without a video stream. Fixed!
  - the frame duration computed from 'ticks_per_second' may
    sometimes too short. Fixed!
  - flushing the codec in 'cff_ffmpeg_file_open_cb' if seeking
    for the last frame of the video
  - DVB subtitles should work now
  - if 'avcodec_receive_frame' fails, rewind only if the packet
    flag 'AV_PKT_FLAG_DISCARD' is not set
  - decoding starts now always with a keyframe, if not seeking
    the first fame
  - storing the packet position for first frame, needed if the
    dts is not set
  - copy the video if first cutpoint is the first frame may fail
    if the dts is not set. Fixed!
  - cutpoints will now be saved with the values frame-dots,
    packet-dts and packet-position. It is possible to load lists
    stored with previous versions of CutterFF.
* Tue Mar 19 2019 enzokiel@kabelmail.de
- Update to version 0.8
  + gui.c
  - memory leak in 'cff_gui_init', 'logname' may not be freed.
    Fixed!
  - memory leak in 'cff_gui_save_image', 'filechooser_utf8str'
    may not be freed. Fixed!
  - max 10 extensions (file filter) can be added for the
    filechooser
  - if copying to another format the matching extension is now
    appended to the filename
  + ffmpeg.c
  - memory leak in 'cff_ffmpeg_copy_cb', 'bsf_ctx' may not be
    freed. Fixed!
  - videos could not loaded if the frames have a duration of
    zero. Fixed!
  - videos may not loaded by some muxers if the first packet is
    not a key frame. Fixed!
  - if copying to another format (especially to AVI) the
    timestamps may incorrect. Fixed!
  - 'cff_ffmpeg_get_format_names' now returns only the formats
    useable for the available streams
  - 'cff_ffmpeg_get_bitstream_filter_names' now returns only the
    filters useable for the available streams
  - 'cff_ffmpeg_get_outformat_extension' returns the extension
    for the given format
* Thu Feb  7 2019 enzokiel@kabelmail.de
- Update to version 0.7
  + gui.c
  - memory leak in 'cff_gui_save_start', 'format_names' may not
    be freed. Fixed!
  - disable menu entry File->Save if there is only one cut point,
    which is the last frame
  - image dialog for saving an image
  - disable okay-button if in the saving dialogs the entry field
    is empty
  + ffmpeg.c
  - buffer may too small for displaying all codecs or formats.
    Fixed!
  - may compute wrong display aspect ratio. Fixed!
  - new function 'cff_ffmpeg_printf_concat' (re)allocates memory
    and writing the string to it
  - log-window displays "Repeated last message n times", if the
    same message should be displayd more then two times
  - scale, encode and save an image
  - at end of copying the bitstream filters will be flushed
  - flushing the codec at end of stream may not work since the
    decode timestamps (dts) are not set. These missing values
    will now computed and saved while opening a file
  - replaced deprecated functions (FFmpeg version 4.0.2)
* Mon Jan 14 2019 enzokiel@kabelmail.de
- Update to version 0.6
  + gui.c
  - save dialog with option for shortest stream duration
  - memory leak in 'cff_gui_save_start', 'bsf_info' may not be
    freed. Fixed!
  - removed double question for overwriting an existing file
  - if copying the log-window to the clipboard it will be
    converted from UNIX to DOS (LF to CRLF)
    (MINGW and GTK-2 only)
  + ffmpeg.c
  - searching to previous frame may fail, if the current
    position is near the last frame and K/I/P-frame is requested.
    Fixed!
  - if at label '_got_picture' the condition 'last_frame != NULL'
    is true, the assignment 'video->vframe.packet[0].pos = -1'
    may overwrite the packet position which was found. Fixed!
  - searching one frame forward or backward may skip a frame with
    a duration less than the picture duration. Fixed!
  - the written file may too short if the duration of either
    audio or video is shorter than the other stream.
    The option 'shortest' was always active, now the user may
    choose if this should happen.
  - may hang if clicking twice on the slider at the same
    position. Fixed!
  - tiny memory leak in 'cff_ffmpeg_get_frame_dts'. Fixed!
  - flushing the codec at end of stream
* Tue Nov 27 2018 enzokiel@kabelmail.de
- Update to version 0.5
  + gui.c
  - memory leak  in 'cff_gui_logwindow_cb'. Fixed!
  - now it is possible to close the log-window while opening a
    video file as long as the progressbar is not visible
  - using an extra thread for opening a video file while the
    progressbar is not visible, which speeds up displaying
    FFmpeg messages in the log-window
  - mutex for the progress-bar
  + ffmpeg.c
  - adding a semaphore if closing the log-window while logging
    is active
  - searching the last frame may fail, if K/I/P-frame is
    requested. Fixed!
  - copying a file do not clear the dirty flag for the cutlist
  + macros-gtk.h
  - 'GuiRecMutex' to 'GuiMutex'
* Tue Oct  2 2018 enzokiel@kabelmail.de
- Update to version 0.4.2
  + gui.c
  - since GTK+ version 3.22.30 the window will not be proper
    drawn after start, but when changing the size of the window
    everything works fine. Testing the cairo surface pointer in
    the redraw functions and create a surface if the pointer is
    NULL fix this bug!
  - removed depricated functions 'gtk_color_button_get_rgb' and
    'gtk_scrolled_window_add_with_viewport', since the required
    GTK+ version is min 3.10. (GTK-3 only)
  + ffmpeg.c
  - works with FFmpeg version 4.0.2.
* Thu Jul 26 2018 jengelh@inai.de
- Use noun phrase in summary, and ensure neutrality of description.
* Thu Jul 19 2018 enzokiel@kabelmail.de
- Enable %%desktop_database_post{un} only for suse_version < 1500.
* Fri Jul 13 2018 enzokiel@kabelmail.de
- Initial package, version 0.4.1
